<template>
    <div class="product-row d-flex flex-wrap align-items-center justify-content-between">
        <div class="product-image col-3">
            <img :src="resolvedImageUrl" :alt="`${props.product.name} image`" class="img-fluid" />
        </div>
        <div class="product-data col-9 d-flex flex-column">
            <div>
                <div class="cart-product-name">{{ props.product.name }}</div>
                <div v-if="props.product.variant" class="cart-variant-name">Talle {{ props.product.variant }}</div>
            </div>
        </div>
        <div class="col-12 text-end">
            <a class="button-delete-item-side mt-auto" @click="removeItem(props.product.id, props.product.variantId)"
                >Eliminar</a
            >
            <span class="cart-product-price">
                <span class="">{{ props.product.quantity }} x </span>
                ${{ formatCurrency(props.product.price) }}
            </span>
        </div>
    </div>
</template>

<script setup>
import { computed } from "vue";
import { cartStore } from "../../js/stores/cart.js";

const store = cartStore();

const props = defineProps({
    product: {
        type: Object,
        required: true,
    },
});

// Method to build image URL
const resolveImageUrl = (file) => {
    if (file === null) {
        return "/build/images/web/nophoto.png";
    }
    const mediaUrl = "/photos";

    const dir = file.substring(0, file.lastIndexOf("/"));
    const baseName = file.substring(file.lastIndexOf("/") + 1);

    return `${mediaUrl}/${dir}/list_${baseName}`;
};

const resolvedImageUrl = computed(() => resolveImageUrl(props.product.image));

const formatCurrency = (value) => {
    return new Intl.NumberFormat("es-AR", {
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
    }).format(value);
};

const removeItem = (productId, variantId) => {
    store.removeItem(productId, variantId);
};
</script>

<style lang="scss">
@use "../../scss/variables" as vars;

.button-delete-item-side {
    font-size: 13px;
    font-weight: 700;
    text-transform: uppercase;
    float: left;
    padding-left: 15px;
    cursor: pointer;
}
</style>
